<?php


namespace Drupal\ipless\EventSubscriber;

use Drupal\Core\Render\HtmlResponse;
use Drupal\ipless\IplessInterface;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;


/**
 * Class HtmlResponseIplessSubscriber
 *
 * @package Drupal\big_pipe\Render
 */
class HtmlResponseIplessSubscriber implements EventSubscriberInterface {

  /**
   * @var \Drupal\ipless\IplessInterface
   */
  protected $ipless;

  /**
   * HtmlResponseIplessSubscriber constructor.
   *
   * @param \Drupal\ipless\IplessInterface $ipless
   */
  public function __construct(IplessInterface $ipless) {
    $this->ipless = $ipless;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    // Run after HtmlResponsePlaceholderStrategySubscriber (priority 5).
    $events[KernelEvents::RESPONSE][] = ['onRespond', 0];

    return $events;
  }

  /**
   * Generate Less files.
   *
   * @param \Symfony\Component\HttpKernel\Event\FilterResponseEvent $event
   *   The event to process.
   */
  public function onRespond(FilterResponseEvent $event) {
    $response = $event->getResponse();

    if (!$response instanceof HtmlResponse) {
      return;
    }

    if ($this->ipless->mustRebuildAll()) {
      $this->ipless->generateAllLibraries();
    }
    else {
      $this->ipless->processOnResponse($response);
    }
  }


}
